@@ -49,15 +49,15 @@ class KKameraConfig : public KCModule
     friend class KameraDeviceSelectDialog;
 
 public:
-    KKameraConfig(QWidget *parent, const QVariantList &);
-    virtual ~KKameraConfig();
+    explicit KKameraConfig(QWidget *parent, const QVariantList &);
+    ~KKameraConfig() override;
 
     // KCModule interface methods
-    void load();
-    void save();
-    void defaults();
+    void load() override;
+    void save() override;
+    void defaults() override;
     int buttons();
-    QString quickHelp() const;
+    QString quickHelp() const override;
 
 protected:
     QString suggestName(const QString &name);
@@ -75,12 +75,12 @@ protected Q_SLOTS:
     void slot_error(const QString &message, const QString &details);
 
 private:
-    void displayGPFailureDialogue(void);
-    void displayGPSuccessDialogue(void);
+    void displayGPFailureDialogue();
+    void displayGPSuccessDialogue();
     void displayCameraAbilities(const CameraAbilities &abilities);
-    void populateDeviceListView(void);
-    void beforeCameraOperation(void);
-    void afterCameraOperation(void);
+    void populateDeviceListView();
+    void beforeCameraOperation();
+    void afterCameraOperation();
 
     // gphoto callbacks
     static void cbGPIdle(GPContext *context, void *data);
